# Table of Contents

- [collaborating-and-managing-data-in-fact-sheets](<./collaborating-and-managing-data-in-fact-sheets.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Collaborating and Managing Data in Fact Sheets](<./Collaborating-and-Managing-Data-in-Fact-Sheets.md>)
  - [Introduction](<./Collaborating-and-Managing-Data-in-Fact-Sheets/Introduction.md>)
  - [Fact Sheet Subscriptions](<./Collaborating-and-Managing-Data-in-Fact-Sheets/Fact-Sheet-Subscriptions.md>)
  - [Commenting on Fact Sheets](<./Collaborating-and-Managing-Data-in-Fact-Sheets/Commenting-on-Fact-Sheets.md>)
  - [Delegating Responsibilities Using To-Dos](<./Collaborating-and-Managing-Data-in-Fact-Sheets/Delegating-Responsibilities-Using-To-Dos.md>)
  - [Storing Resources on Fact Sheets](<./Collaborating-and-Managing-Data-in-Fact-Sheets/Storing-Resources-on-Fact-Sheets.md>)
  - [Managing Transformations Associated with Fact Sheets](<./Collaborating-and-Managing-Data-in-Fact-Sheets/Managing-Transformations-Associated-with-Fact-Sheets.md>)
  - [Answering Survey Questions](<./Collaborating-and-Managing-Data-in-Fact-Sheets/Answering-Survey-Questions.md>)
  - [Reviewing the Fact Sheet Update Log](<./Collaborating-and-Managing-Data-in-Fact-Sheets/Reviewing-the-Fact-Sheet-Update-Log.md>)
  - [Right Side Pane of Fact Sheet](<./Collaborating-and-Managing-Data-in-Fact-Sheets/Right-Side-Pane-of-Fact-Sheet.md>)
